Learn R Programming

rotulador (version 1.0.0)

rotulador-package: rotulador: Useful Functions for Programming and Generating Documents

Description

Tools to help developers and producers manipulate R objects and outputs. It includes tools for displaying results and objects, and for formatting them in the correct format.

Arguments

Author

Maintainer: Tanguy Barthelemy tangbarth@hotmail.fr

See Also